***** Replication file for "Designing and Analyzing Powerful Experiments: Practical Tips for Applied Researchers"
*** David McKenzie, prepared for the journal Fiscal Studies

*** Data files sourced from:
*Iacovone, Leonardo, David McKenzie and Rachael Meager (2024). "Replication package of "Bayesian *Impact Evaluation with Informative Priors: An Application to a Colombian Management and Export * Improvement Program" [Data set]." In Econometrica. Zenodo. https://doi.org/10.5281/zenodo.14430028 



* Set file paths
   * Main Directory: replace with your filepath
 	if c(username)=="wb200090"{
    global maindir"C:/Users/wb200090/Dropbox/DavidMcKenzie/Misc/LisbonSummerSchool/FiscalStudiesPaper/ColombiaData"
    }
 	if "`c(username)'" == "your user name" {
	global maindir "your path"
	}
	
* Set directories 
global figures "$maindir/output/figures"




use "$maindir/ExportOutcomes.dta", clear
* merge in baseline data
sort Id
merge Id using "$maindir/BaselineConstructed", sort
tab _merge
drop _merge

* express 2017 export value in 1000s 
gen exportamount2017=fobdo17/1000
label var exportamount2017 "2017 Export Value"

******* Figure 1: Baseline Employees and Exports of Colombian Firms in Export Improvement Experiment

** Histogram of number of workers in 2016
twoway (histogram employees2016, color(blue%30) width(50) freq), xtitle("Number of Workers") title("Number of Workers") ytitle("Frequency") saving("$figures/fig1a.gph", replace)

** Histogram of value of exports in 2017
twoway (histogram exportamount2017, color(red%30) freq),  title("Value of Exports ") xtitle("Value of Exports (1000s of USD)") ytitle("Frequency") saving("$figures/fig1b.gph", replace)


graph combine  "$figures/fig1a.gph" "$figures/fig1b.gph", col(2) scheme(s1mono) saving("$figures/FSFigure1.gph", replace)

graph export "$figures/FSFigure1.png", replace
graph export "$figures/FSFigure1.pdf", replace


*** statistics reported in text 
* Section 3: Summary Statistics on Employees and Exports
sum employees2016, de
count if exportamount2017==0
sum exportamount2017, de

* Section 4a: Summary Statistics if Change Estimand on Employment
sum employees2016 if employees2016<r(p95), de 
*** employment power with full sample versus 95% of sample 
sampsi 73 93, n1(100) n2(100) sd1(106)
sampsi 53 73, n1(95) n2(95) sd1(50)

* Summary statistics if change export outcome we consider
gen sampleX=exportamount2017<r(p95)
sum exportamount2017 if sampleX==1, de
sum exportamount2017, de
gen win_exportamount2017=exportamount2017
replace win_exportamount2017=r(p95) if win_exportamount2017>r(p95)
sum win_exportamount2017, de
gen export100=cond(exportamount2017>100,1,0)
sum export100 

* export power on different outcomes for 50% increase
* unwinsorized
sampsi 338 507, n1(100) n2(100) sd1(1170)
* winsorized
sampsi 220 330, n1(100) n2(100) sd1(452)
* binary
sampsi 0.3 0.45, n1(100) n2(100) sd1(0.46)
* binary with variance change
power twomeans 0.3 0.45, n1(100) n2(100) sd1(0.46) sd2(0.497)
* binary with proportions formula
power twoproportions 0.3 0.45, n1(100) n2(100)

*** Section 5a: oversubscription vs screening on interest
sampsi 100 107.5, n1(500) n2(500) sd1(50) 
sampsi 100 122.5, n1(125) n2(125) sd1(50)

***********************************************************
